@@ -1,38 +1,41 @@
-### Dstat battery plugin
-### Displays battery information from ACPI
-###
-### Authority: dag@wieers.com
+### Author: Dag Wieers <dag$wieers,com>
 
-global string
-import string
+class dstat_plugin(dstat):
+    """
+    Percentage of remaining battery power as reported by ACPI.
+    """
 
-class dstat_battery(dstat):
     def __init__(self):
+        self.file = file
         self.name = 'battery'
-        self.format = ('f', 4, 34)
-        self.vars = []
+        self.type = 'p'
+        self.width = 4
+        self.scale = 34
+
+    def vars(self):
+        ret = []
         for battery in os.listdir('/proc/acpi/battery/'):
             for line in dopen('/proc/acpi/battery/'+battery+'/state').readlines():
-                l = string.split(line)
+                l = line.split()
                 if len(l) < 2: continue
                 if l[0] == 'present:' and l[1] == 'yes':
-                    self.vars.append(battery)
-#       self.nick = [string.lower(name) for name in self.vars]
-        self.nick = []
-        for name in self.vars:
-            self.nick.append(string.lower(name))
-        self.init(self.vars, 1)
+                    ret.append(battery)
+        ret.sort()
+        return ret
+
+    def nick(self):
+        return [name.lower() for name in self.vars]
 
     def extract(self):
         for battery in self.vars:
             for line in dopen('/proc/acpi/battery/'+battery+'/info').readlines():
-                l = string.split(line)
+                l = line.split()
                 if len(l) < 4: continue
                 if l[0] == 'last':
                     full = int(l[3])
                     break
             for line in dopen('/proc/acpi/battery/'+battery+'/state').readlines():
-                l = string.split(line)
+                l = line.split()
                 if len(l) < 3: continue
                 if l[0] == 'remaining':
                     current = int(l[2])
