@@ -1,17 +1,19 @@
-### Dstat DBUS plugin
-### Displays dbus sessions
-###
-### Authority: dag@wieers.com
+### Author: Dag Wieers <dag$wieers,com>
+
+class dstat_plugin(dstat):
+    """
+    Number of active dbus sessions.
+    """
 
-class dstat_dbus(dstat):
     def __init__(self):
         self.name = 'dbus'
-        self.format = ('d', 3, 100)
+        self.type = 'd'
+        self.width = 3
+        self.scale = 100
         self.nick = ('sys', 'ses')
         self.vars = ('system', 'session')
-        self.init(self.vars, 1)
 
-    def check(self): 
+    def check(self):
 #       dstat.info(1, 'The dbus module is an EXPERIMENTAL module.')
         try:
             global dbus
@@ -24,7 +26,6 @@ class dstat_dbus(dstat):
                     self.sesbus = None
             except:
                 raise Exception, 'Unable to connect to dbus message bus'
-            return True
         except:
             raise Exception, 'Needs python-dbus module'
 
