@@ -1,29 +1,31 @@
-# dstat plugin for MySQL 5 connections 
-# 2007-09-04 - lefred@inuits.be
-global MySQLdb
-import MySQLdb
-global string, select
-import string, select
+### Author: <lefred$inuits,be>
 
 global mysql_user
-global mysql_pwd
 mysql_user = os.getenv('DSTAT_MYSQL_USER') or os.getenv('USER')
+
+global mysql_pwd
 mysql_pwd = os.getenv('DSTAT_MYSQL_PWD')
 
-class dstat_mysql5_conn(dstat):
+class dstat_plugin(dstat):
+    """
+    Plugin for MySQL 5 connections.
+    """
+
     def __init__(self):
         self.name = 'mysql5 conn'
-        self.format = ('f', 4, 1)
-        self.vars = ('Threads_connected', 'Threads')
+        self.type = 'f'
+        self.width = 4
+        self.scale = 1
         self.nick = ('ThCon', '%Con')
-        self.init(self.vars, 1)
+        self.vars = ('Threads_connected', 'Threads')
 
     def check(self): 
-            try:
-                self.db=MySQLdb.connect(user=mysql_user, passwd=mysql_pwd)
-            except:
-                raise Exception, 'Cannot interface with MySQL server'
-            return True
+        global MySQLdb
+        import MySQLdb
+        try:
+            self.db = MySQLdb.connect(user=mysql_user, passwd=mysql_pwd)
+        except Exception, e:
+            raise Exception, 'Cannot interface with MySQL server, %s' % e
 
     def extract(self):
         try:
@@ -33,14 +35,14 @@ class dstat_mysql5_conn(dstat):
             c.execute("""show global status like 'Threads_connected';""")
             thread = c.fetchone()
             if thread[0] in self.vars:
-                    self.cn2[thread[0]] = float(thread[1])
-                    self.cn2['Threads'] = (float(thread[1]) / float(max[1]) * float(100)) 
+                self.set2[thread[0]] = float(thread[1])
+                self.set2['Threads'] = float(thread[1] / float(max[1]) 1.0 * 100)
 
             for name in self.vars:
-                self.val[name] = self.cn2[name] * 1.0 /tick
+                self.val[name] = self.set2[name] * 1.0 / elapsed
 
             if step == op.delay:
-                self.cn1.update(self.cn2)
+                self.set1.update(self.set2)
 
         except Exception, e:
             for name in self.vars:
