@@ -1,18 +1,17 @@
-global glob
-import glob
+### Author: Dag Wieers <dag@wieers.com>
 
-class dstat_postfix(dstat):
+class dstat_plugin(dstat):
     def __init__(self):
         self.name = 'postfix'
-        self.format = ('d', 4, 100)
+        self.type = 'd'
+        self.width = 4
+        self.scale = 100
         self.vars = ('incoming', 'active', 'deferred', 'bounce', 'defer')
         self.nick = ('inco', 'actv', 'dfrd', 'bnce', 'defr')
-        self.init(self.vars, 1)
 
-    def check(self): 
+    def check(self):
         if not os.access('/var/spool/postfix/active', os.R_OK):
             raise Exception, 'Cannot access postfix queues'
-        return True
 
     def extract(self):
         for item in self.vars:
