@@ -1,19 +1,19 @@
-### FIXME: Should read /var/log/mail/statistics or /etc/mail/statistics (format ?)
-global glob
-import glob
+### Author: Dag Wieers <dag@wieers.com>
 
-class dstat_sendmail(dstat):
+### FIXME: Should read /var/log/mail/statistics or /etc/mail/statistics (format ?)
+
+class dstat_plugin(dstat):
     def __init__(self):
         self.name = 'sendmail'
-        self.format = ('d', 4, 100)
+        self.type = 'd'
+        self.width = 4
+        self.scale = 100
         self.vars = ('queue',)
         self.nick = ('queu',)
-        self.init(self.vars, 1)
 
     def check(self):
         if not os.access('/var/spool/mqueue', os.R_OK):
             raise Exception, 'Cannot access sendmail queue'
-        return True
 
     def extract(self):
         self.val['queue'] = len(glob.glob('/var/spool/mqueue/qf*'))
