@@ -1,16 +1,16 @@
-class dstat_utmp(dstat):
+class dstat_plugin(dstat):
     def __init__(self):
         self.name = 'utmp'
-        self.format = ('d', 3, 10)
+        self.type = 'd'
+        self.width = 3
+        self.scale = 10
         self.nick = ('ses', 'usr', 'adm' )
         self.vars = ('sessions', 'users', 'root')
-        self.init(self.vars, 1)
 
     def check(self): 
         try:
             global utmp
             import utmp
-            return True
         except:
             raise Exception, 'Needs python-utmp module'
 
