@@ -1,15 +1,16 @@
 global iwlibs
 from pythonwifi import iwlibs
 
-class dstat_wifi(dstat):
+class dstat_plugin(dstat):
     def __init__(self):
         self.name = 'wifi'
-        self.format = ('d', 3, 33)
+        self.type = 'd'
+        self.width = 3
+        self.scale = 33
         self.check()
         self.vars = iwlibs.getNICnames()
-        self.name = self.vars
         self.nick = ('lnk', 's/n')
-        self.init(self.vars, 2)
+        self.cols = 2
 
     def check(self): 
         global iwlibs
@@ -17,7 +18,6 @@ class dstat_wifi(dstat):
             from pythonwifi import iwlibs
         except:
             raise Exception, 'Needs python-wifi module'
-        return True
 
     def extract(self):
         for name in self.vars:
